wagoe.admin.core.db-errors

Reading database constraint errors the admin can explain to a user.

Reading database constraint errors the admin can explain to a user.
raw docstring

foreign-key-violationclj

(foreign-key-violation message)

{:column c} when message is a foreign-key violation, c in lower case or nil when the driver does not name it (SQLite); nil when it is not one.

`{:column c}` when `message` is a foreign-key violation, c in lower case or
nil when the driver does not name it (SQLite); nil when it is not one.
sourceraw docstring

not-null-violation-columnclj

(not-null-violation-column message)

The column a NOT NULL violation message names, in lower case, or nil when the message is not one. Reads the H2, PostgreSQL, SQLite and MySQL texts.

The column a NOT NULL violation `message` names, in lower case, or nil when
the message is not one. Reads the H2, PostgreSQL, SQLite and MySQL texts.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries