wagoe.admin.shell.http.handlers.detail

Entity detail / edit page handlers (view existing + new-entity form).

Entity detail / edit page handlers (view existing + new-entity form).
raw docstring

entity-detail-handlerclj

(entity-detail-handler admin-service schema-provider config)

Handler for entity detail/edit page.

Shows form for editing existing entity.

Handler for entity detail/edit page.

Shows form for editing existing entity.
sourceraw docstring

new-child-row-handlerclj

(new-child-row-handler _admin-service schema-provider config)

GET /:entity/new/rows/:child — one blank child row for the create form of :entity, which HTMX appends (BOU-570).

GET /:entity/new/rows/:child — one blank child row for the create form of
`:entity`, which HTMX appends (BOU-570).
sourceraw docstring

new-entity-handlerclj

(new-entity-handler admin-service schema-provider config)

Handler for new entity creation form.

Shows empty form for creating new entity. If the entity declares a :create-redirect-url, redirects there instead (used for split-table entities that need a dedicated create flow).

Handler for new entity creation form.

Shows empty form for creating new entity. If the entity declares a
`:create-redirect-url`, redirects there instead (used for split-table
entities that need a dedicated create flow).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries